@@ -19,6 +19,7 @@
 #define TRACK_WRITER_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QElapsedTimer>
@@ -39,7 +40,7 @@ namespace Kwave
      * @warning THIS CLASS IS NOT THREADSAFE! It is intended to be owned by
      *          and used from only one thread.
      */
-    class Q_DECL_EXPORT TrackWriter: public Kwave::Writer
+    class LIBKWAVE_EXPORT TrackWriter: public Kwave::Writer
     {
         Q_OBJECT
     public:
@@ -59,7 +60,7 @@ namespace Kwave
         /**
          * Destructor.
          */
-        virtual ~TrackWriter() Q_DECL_OVERRIDE;
+        ~TrackWriter() override;
 
         /**
          * Flush the content of a buffer. Normally the buffer is the
@@ -74,7 +75,7 @@ namespace Kwave
          */
         virtual bool write(const Kwave::SampleArray &buffer,
                            unsigned int &count)
-            Q_DECL_OVERRIDE;
+            override;
 
     private:
 
