@@ -35,16 +35,16 @@ namespace Kwave
     public:
 
         /** Constructor */
-        explicit NoiseGenerator(QObject *parent = Q_NULLPTR);
+        explicit NoiseGenerator(QObject *parent = nullptr);
 
         /** Destructor */
-        virtual ~NoiseGenerator() Q_DECL_OVERRIDE;
+        ~NoiseGenerator() override;
 
         /**
          * produces a block of noise,
          * @see Kwave::SampleSource::goOn()
          */
-        virtual void goOn() Q_DECL_OVERRIDE;
+        void goOn() override;
 
     signals:
 
