@@ -32,7 +32,6 @@
 #include "libkwave/SampleArray.h"
 
 class QPaintEvent;
-class QTimer;
 
 namespace Kwave
 {
@@ -44,13 +43,13 @@ namespace Kwave
         explicit LevelMeter(QWidget *parent);
 
         /** Destructor */
-        virtual ~LevelMeter() Q_DECL_OVERRIDE;
+        ~LevelMeter() override;
 
         /** @see QWidget::paintEvent */
-        virtual void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+        void paintEvent(QPaintEvent *) override;
 
         /** @see QWidget::resizeEvent */
-        virtual void resizeEvent(QResizeEvent *) Q_DECL_OVERRIDE;
+        void resizeEvent(QResizeEvent *) override;
 
     public slots:
 
